summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmnormaledit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmnormaledit.h')
-rw-r--r--kpovmodeler/pmnormaledit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmnormaledit.h b/kpovmodeler/pmnormaledit.h
index 72ca9d12..f3fa45b7 100644
--- a/kpovmodeler/pmnormaledit.h
+++ b/kpovmodeler/pmnormaledit.h
@@ -36,12 +36,13 @@ class PMFloatEdit;
class PMNormalEdit : public PMTextureBaseEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMNormalEdit with parent and name
*/
- PMNormalEdit( TQWidget* parent, const char* name = 0 );
+ PMNormalEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -36,12 +36,13 @@ class PMFloatEdit;
public:
/**
- * Creates a PMNormalEdit with parent and name
+ * Creates a PMNormalEdit with tqparent and name
*/